@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : PM
-Version : 1.0.0
+Version : 1.0.1
 Author  : Stefano Covino
-Date    : 22/08/2012
+Date    : 01/07/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -13,13 +13,14 @@ Usage   : to be imported
 Remarks :
 
 History : (22/08/2012) First version.
+        : (01/07/2013) Check of parameter names.
 
 """
 
 import numpy
 
 
-def Full ((az,alt),(f_AN,f_AE,f_NPAE,f_BNP,f_AES,f_AEC,f_EES,f_EEC,f_AOFS,f_EOFS)):
+def Full ((az,alt),(f_AAN,f_EAE,f_NPAE,f_BNP,f_AES,f_AEC,f_EES,f_EEC,f_AOFS,f_EOFS)):
     # AN: error in the leveling of the telescope toward north
     # AE: error in the leveling of the telescope toward east
     # NPAE: non-perpendicularity of the azimuth and elevation axis
@@ -27,7 +28,7 @@ def Full ((az,alt),(f_AN,f_AE,f_NPAE,f_BNP,f_AES,f_AEC,f_EES,f_EEC,f_AOFS,f_EOFS
     # AES, AEC, EES, EEC:  eccentricity of the encoders
     # AOFS: azimuth zero point correction
     # EOFS: altitude zero point correction
-    naz = az + f_AN * numpy.sin(numpy.radians(az)) * numpy.tan(numpy.radians(alt)) - f_AE * numpy.cos(numpy.radians(az)) * numpy.tan(numpy.radians(alt)) + f_NPAE * numpy.tan(numpy.radians(alt))  - f_BNP / numpy.cos(numpy.radians(alt)) + f_AOFS + f_AES * numpy.sin(numpy.radians(az)) + f_AEC * numpy.cos(numpy.radians(az))
-    nalt = alt + f_AN * numpy.cos(numpy.radians(az)) + f_AE * numpy.sin(numpy.radians(az)) + f_EOFS + f_EES * numpy.sin(numpy.radians(alt)) + f_EEC * numpy.cos(numpy.radians(alt))
+    naz = az + f_AAN * numpy.sin(numpy.radians(az)) * numpy.tan(numpy.radians(alt)) - f_EAE * numpy.cos(numpy.radians(az)) * numpy.tan(numpy.radians(alt)) + f_NPAE * numpy.tan(numpy.radians(alt))  - f_BNP / numpy.cos(numpy.radians(alt)) + f_AOFS + f_AES * numpy.sin(numpy.radians(az)) + f_AEC * numpy.cos(numpy.radians(az))
+    nalt = alt + f_AAN * numpy.cos(numpy.radians(az)) + f_EAE * numpy.sin(numpy.radians(az)) + f_EOFS + f_EES * numpy.sin(numpy.radians(alt)) + f_EEC * numpy.cos(numpy.radians(alt))
     return naz, nalt
 
