@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : REM
-Version : 1.0.10
+Version : 1.0.15
 Author  : Stefano Covino
-Date    : 22/03/2013
+Date    : 13/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -24,9 +24,13 @@ History : (16/12/2011) First version.
         : (29/08/2012) V. 1.3.0.
         : (31/08/2012) V. 1.3.1b1.
         : (22/03/2013) V. 1.3.1.
+        : (22/04/2013) New ROS2 pixel size. and V. 1.3.2b1
+        : (21/06/2013) New camera code.
+        : (01/07/2013) Parameter name check in REM pointing model.
+        : (13/08/2013) Better minimization in pointing model computation. V. 1.3.2.
 """
 
-__version__ = '1.3.1'
+__version__ = '1.3.2'
 
 
 
@@ -36,12 +40,13 @@ __all__ =  ['GetObj', 'GetREMSite']
 
 # REM pixel size
 REMIRPixSize    = 1.22
-ROSSPixSize     = 0.54
+ROSSPixSize     = 0.59
 
 
 # Constants
 REMIR   =   'REMIR'
 ROSS    =   'REM-ROSS'
+ROS2    =   'REM-ROS2'
 CAMERA  =   'INSTRUME'
 
 # External commands
